==> dfipy-7.0.0.tar.gz: dfipy-7.0.0/README.md <==
<img src="docs/source/_static/gs_logo.png" align="right">

[![Python versions](https://img.shields.io/pypi/pyversions/dfipy.svg)](https://pypi.python.org/pypi/dfipy/)
[![PyPI version](https://badge.fury.io/py/dfipy.svg)](https://badge.fury.io/py/dfipy)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://timothycrosley.github.io/isort/)

# DFI API wrapper

## About

- Python library created by [General System](https://www.generalsystem.com/) and publicly available on [github](https://github.com/thegeneralsystem) to query and experiment with the Data Flow Index (DFI) platform.
- DFI provides the user with an unparalled foundation and scalable solution for processing high velocity, high volume spatiotemporal workloads for any geospatial data science need.
- [Read the code documentation](https://dfipy.docs.generalsystem.com/)
- [Read the whitepaper](https://assets.website-files.com/636ce900cf2e67aab6340642/643807134214aebc2b29849c_General%20System_The%20Data%20Flow%20Index%20Whitepaper%20_%20Nov%2022.pdf)

## Quickstart

- Contact General System to obtain an API token.
- **Install Python SDK:**

  ```bash
  pip install dfipy
  ```

- Start querying with [DfiPy Examples](https://github.com/thegeneralsystem/dfipy-examples)

## Licence

- Copyright (c) 2023, General System Group Limited.

- DFIPy is provided as it is and copyrighted under [Apache2 License](LICENCE).

- DFIPy is currently released on public pypi in beta, strictly for testing and evaluation purposes.

==> dfipy-8.0.0.tar.gz: dfipy-8.0.0/README.md <==
<img src="docs/source/_static/gs_logo.png" align="right">

[![Python versions](https://img.shields.io/pypi/pyversions/dfipy.svg)](https://pypi.python.org/pypi/dfipy/)
[![PyPI version](https://badge.fury.io/py/dfipy.svg)](https://badge.fury.io/py/dfipy)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://timothycrosley.github.io/isort/)

# DFI API wrapper

## About

- Python library created by [General System](https://www.generalsystem.com/) and publicly available on [github](https://github.com/thegeneralsystem) to query and experiment with the Data Flow Index (DFI) platform.
- DFI provides the user with an unparalled foundation and scalable solution for processing high velocity, high volume spatiotemporal workloads for any geospatial data science need.
- [Read the code documentation](https://dfipy.docs.generalsystem.com/)
- [Read the whitepaper](https://assets.website-files.com/636ce900cf2e67aab6340642/643807134214aebc2b29849c_General%20System_The%20Data%20Flow%20Index%20Whitepaper%20_%20Nov%2022.pdf)

## Quickstart

- Contact General System to obtain an API token.
- **Install Python SDK:**

  ```bash
  pip install dfipy
  ```

- Start querying with [dfipy Examples](https://github.com/thegeneralsystem/dfipy-examples)

## Licence

- Copyright (c) 2023, General System Group Limited.

- DFIPy is provided as it is and copyrighted under [Apache2 License](LICENCE).

- DFIPy is currently released on public pypi in beta, strictly for testing and evaluation purposes.
